==> gs-core-1.3-sources.jar: org/graphstream/stream/file/FileSourcePajek.java <==
/*
 * Copyright 2006 - 2015
 *     Stefan Balev     <stefan.balev@graphstream-project.org>
 *     Julien Baudry    <julien.baudry@graphstream-project.org>
 *     Antoine Dutot    <antoine.dutot@graphstream-project.org>
 *     Yoann Pigné      <yoann.pigne@graphstream-project.org>
 *     Guilhelm Savin   <guilhelm.savin@graphstream-project.org>
 * 
 * This file is part of GraphStream <http://graphstream-project.org>.
 * 
 * GraphStream is a library whose purpose is to handle static or dynamic
 * graph, create them from scratch, file or any source and display them.
 * 
 * This program is free software distributed under the terms of two licenses, the
 * CeCILL-C license that fits European law, and the GNU Lesser General Public
 * License. You can  use, modify and/ or redistribute the software under the terms
 * of the CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 * URL <http://www.cecill.info> or under the terms of the GNU LGPL as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C and LGPL licenses and that you accept their terms.
 */
package org.graphstream.stream.file;

import java.io.Reader;

import org.graphstream.stream.file.pajek.PajekParser;

import org.graphstream.util.parser.Parser;
import org.graphstream.util.parser.ParserFactory;

/**
 * A parser for the Pajek NET format.
 * 
 * This should support most the NET file format. However this format seems
 * to have numerous derivative that may not be known to us. It parses the
 * edges/arcs, edgeslist/arclist, and matrix notations. It understands a
 * large part of the formating notation, and transform it to CSS "ui.style"
 * attribute stored on nodes and edges.
 * 
 * The standard extension for such files is ".net".
 */
public class FileSourcePajek extends FileSourceParser {
	public ParserFactory getNewParserFactory() {
		return new ParserFactory() {
			public Parser newParser(Reader reader) {
				return new PajekParser(FileSourcePajek.this, reader);
			}
		};
	}
}

==> gs-core-2.0-sources.jar: org/graphstream/stream/file/FileSourcePajek.java <==
/*
 * This file is part of GraphStream <http://graphstream-project.org>.
 * 
 * GraphStream is a library whose purpose is to handle static or dynamic
 * graph, create them from scratch, file or any source and display them.
 * 
 * This program is free software distributed under the terms of two licenses, the
 * CeCILL-C license that fits European law, and the GNU Lesser General Public
 * License. You can  use, modify and/ or redistribute the software under the terms
 * of the CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 * URL <http://www.cecill.info> or under the terms of the GNU LGPL as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C and LGPL licenses and that you accept their terms.
 */

/**
 * @since 2011-07-21
 * 
 * @author Guilhelm Savin <guilhelm.savin@graphstream-project.org>
 * @author Hicham Brahimi <hicham.brahimi@graphstream-project.org>
 */
package org.graphstream.stream.file;

import java.io.Reader;

import org.graphstream.stream.file.pajek.PajekParser;

import org.graphstream.util.parser.Parser;
import org.graphstream.util.parser.ParserFactory;

/**
 * A parser for the Pajek NET format.
 * 
 * This should support most the NET file format. However this format seems to
 * have numerous derivative that may not be known to us. It parses the
 * edges/arcs, edgeslist/arclist, and matrix notations. It understands a large
 * part of the formating notation, and transform it to CSS "ui.style" attribute
 * stored on nodes and edges.
 * 
 * The standard extension for such files is ".net".
 */
public class FileSourcePajek extends FileSourceParser {
	public ParserFactory getNewParserFactory() {
		return new ParserFactory() {
			public Parser newParser(Reader reader) {
				return new PajekParser(FileSourcePajek.this, reader);
			}
		};
	}
}
